@@ -1,6 +1,7 @@
 from .zhuobie import *
 from .MCTS import *
 from .socketIO import *
+import time
 
 
 class Wrapped(Client):
@@ -9,11 +10,13 @@ class Wrapped(Client):
         self.game = Game()
         self.tree = None
         self.first_run = True
+        time.sleep(0.5)
         self.set_data('000000ZZZ0000000zzz000000')
 
     def on_update(self, chesspos):
-        if chesspos == self.chesspos:
+        if chesspos == self.chesspos or self.first_run and chesspos == '000000ZZZ0000000zzz000000':
             return
+        # print("\n".join([chesspos[i:i+5] for i in range(0, 25, 5)]))
         state = []
         change = {'z': 1, 'Z': -1, '0': 0}
         for line in [chesspos[6:9], chesspos[11:14], chesspos[16:19]]:
@@ -25,10 +28,14 @@ class Wrapped(Client):
             self.tree = Tree(state, self.game, -1, max_node=500)
             self.first_run = False
         else:
+            # print([child.action for child in self.tree.root.children])
+            # tmp.append(self.tree.root)
             self.tree.update_by_state(state)
-        new_state = self.tree.search().state
+        best_child = self.tree.search()
+        new_state = best_child.state
+        turn = best_child.turn
         new_chesspos = '00000'
-        new_change = {1:'z',-1:'Z',0:'0'}
+        new_change = {1: 'z', -1: 'Z', 0: '0'}
         for line in new_state:
             new_chesspos += '0'
             for spot in line:
@@ -37,6 +44,9 @@ class Wrapped(Client):
         new_chesspos += '00000'
         self.chesspos = new_chesspos
         self.set_data(new_chesspos)
+        time.sleep(0.5)
+        if self.tree.root.game.end_game(new_state, turn):
+            self.disconnect()
 
 
 def main(userId):
